@@ -1,7 +1,5 @@
 /*
-    $Id: cdtext.hpp,v 1.2 2008/03/25 15:59:10 karl Exp $
-
-    Copyright (C) 2005, 2008 Rocky Bernstein <rocky@gnu.org>
+    Copyright (C) 2005, 2008, 2012 Rocky Bernstein <rocky@gnu.org>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +26,16 @@ const char *field2str (cdtext_field_t i)
   return cdtext_field2str (i);
 }
 
+const char *genre2str (cdtext_genre_t i) 
+{
+  return cdtext_genre2str (i);
+}
+
+const char *lang2str (cdtext_lang_t i) 
+{
+  return cdtext_lang2str (i);
+}
+
 /*! returns an allocated string associated with the given field.  NULL is
   returned if key is CDTEXT_INVALID or the field is not set.
   
@@ -37,15 +45,9 @@ const char *field2str (cdtext_field_t i)
   have to be freed.
   
 */
-char *get (cdtext_field_t key) 
+char *get (cdtext_field_t key, track_t i_track) 
 {
-  return cdtext_get (key, p_cdtext);
-}
-
-/*! returns the C cdtext_t pointer associated with this object. */
-cdtext_t *get () 
-{
-  return p_cdtext;
+  return cdtext_get (p_cdtext, key, i_track);
 }
 
 /*! returns a const string associated with the given field.  NULL is
@@ -58,26 +60,41 @@ cdtext_t *get ()
   cdtext object.
 
 */
-const char *getConst (cdtext_field_t key) 
+const char *getConst (cdtext_field_t key, track_t i_track) 
 {
-  return cdtext_get_const (key, p_cdtext);
-}
-
-/*!
-  returns enum of keyword if key is a CD-Text keyword, 
-  returns MAX_CDTEXT_FIELDS non-zero otherwise.
-*/
-cdtext_field_t isKeyword (const char *key) 
-{
-  return cdtext_is_keyword (key);
+  return cdtext_get_const (p_cdtext, key, i_track);
 }
 
 /*! 
   sets cdtext's keyword entry to field 
 */
-void set (cdtext_field_t key, const char *value) 
+void set (cdtext_field_t key, track_t i_track, const uint8_t *value, const char *charset) 
 {
-  cdtext_set (key, value, p_cdtext);
+  cdtext_set (p_cdtext, key, value, i_track, charset);
+}
+
+/*!
+  returns the selected language
+*/
+cdtext_lang_t getLanguage()
+{
+  return cdtext_get_language(p_cdtext);
+}
+
+/*!
+  selects a language
+*/
+bool selectLanguage(cdtext_lang_t lang)
+{
+  return cdtext_select_language(p_cdtext, lang);
+}
+
+/*!
+ returns a list of available languages
+*/
+cdtext_lang_t *listLanguages()
+{
+  return cdtext_list_languages(p_cdtext);
 }
 
 
