@@ -29,17 +29,10 @@
 /** Application Interface or Protocol version number. If the public
  *  interface changes, we increase this number.
  */
-#define CDIO_API_VERSION 5
+#define CDIO_API_VERSION 6
 
 #include <cdio/version.h>
 #include <cdio/types.h>
-#ifdef  HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-#ifdef  HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
 #include <cdio/sector.h>
 
 #ifdef __cplusplus
@@ -52,9 +45,6 @@ extern "C" {
   /** This is an opaque structure for the CD object. */
   typedef struct _CdIo CdIo_t; 
 
-  /** This is an opaque structure for the CD-Text object. */
-  typedef struct cdtext cdtext_t;
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
@@ -64,6 +54,9 @@ extern "C" {
 */
 #include <cdio/device.h>
 
+/* CD-Text-related functions. */
+#include <cdio/cdtext.h>
+
 /* Disc-related functions. */
 #include <cdio/disc.h>
 
@@ -72,9 +65,6 @@ extern "C" {
 */
 #include <cdio/read.h>
 
-/* CD-Text-related functions. */
-#include <cdio/cdtext.h>
-
 /* Track-related functions. */
 #include <cdio/track.h>
 
