@@ -1,7 +1,5 @@
 /*
-    $Id: types.h,v 1.37 2008/03/25 15:59:09 karl Exp $
-
-    Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008
+    Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008, 2012
                   Rocky Bernstein <rocky@gnu.org>
     Copyright (C) 2000 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -24,44 +22,42 @@
  */
 
 
-#ifndef __CDIO_TYPES_H__
-#define __CDIO_TYPES_H__
+#ifndef CDIO_TYPES_H_
+#define CDIO_TYPES_H_
 
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
-#ifndef EXTERNAL_LIBCDIO_CONFIG_H
-#define EXTERNAL_LIBCDIO_CONFIG_H
-#include <cdio/cdio_config.h>
-#endif
-
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
-  /* provide some C99 definitions */
-
-#if defined(HAVE_SYS_TYPES_H) 
+/* If <sys/types.h> is not available on your platform please
+   contact the libcdio mailing list so that we can fix it! */
+#if !defined(ARE_THERE_STILL_ENVS_WITHOUT_SYS_TYPES) 
 #include <sys/types.h>
 #endif 
 
-#if defined(HAVE_STDINT_H)
-# include <stdint.h>
-#elif defined(HAVE_INTTYPES_H)
-# include <inttypes.h>
-#elif defined(AMIGA) || defined(__linux__)
-  typedef u_int8_t uint8_t;
-  typedef u_int16_t uint16_t;
-  typedef u_int32_t uint32_t;
-  typedef u_int64_t uint64_t;
+#if defined(AMIGA)
+typedef u_int8_t uint8_t;
+typedef u_int16_t uint16_t;
+typedef u_int32_t uint32_t;
+typedef u_int64_t uint64_t;
 #else
-  /* warning ISO/IEC 9899:1999 <stdint.h> was missing and even <inttypes.h> */
-  /* fixme */
-#endif /* HAVE_STDINT_H */
-  
+/* If <stdint.h> is not available on your platform please
+   contact the libcdio mailing list so that we can fix it!
+   For MSVC, you can find both a public domain stdint.h and
+   inttypes.h in the MSVC/missing directory of libcdio. */
+#include <stdint.h>
+#endif
+
 typedef uint8_t ubyte;
 
+/* MSVC does not define mode_t and ssize_t by default. The way
+   to compensate for missing UNIX types is to include a custom
+   unistd.h that defines them. Such a file is provided with
+   the libcdio source, in the MSVC/missing directory */
+#if defined(_MSC_VER)
+#include <unistd.h>
+#endif
+
   /* default HP/UX macros are broken */
 #if defined(__hpux__)
 # undef UINT16_C
@@ -108,15 +104,24 @@ typedef uint8_t ubyte;
 #endif
   
 #ifndef __cplusplus
-# if defined(HAVE_STDBOOL_H)
-#  include <stdbool.h>
-# else
-   /* ISO/IEC 9899:1999 <stdbool.h> missing -- enabling workaround */
-  
-#   define false   0
-#   define true    1
-#   define bool uint8_t
-# endif /*HAVE_STDBOOL_H*/
+
+/* All the stdbool.h seem to define those */
+#ifndef __bool_true_false_are_defined
+#define __bool_true_false_are_defined 1
+
+#undef bool
+#undef true
+#undef false
+
+#ifdef _Bool
+#define bool _Bool
+#else
+#define bool unsigned char
+#endif
+#define true 1
+#define false 0
+
+#endif /* __bool_true_false_are_defined */
 #endif /*C++*/
   
   /* some GCC optimizations -- gcc 2.5+ */
@@ -146,18 +151,21 @@ typedef uint8_t ubyte;
 #define GNUC_PACKED
 #endif  /* !__GNUC__ */
   
-#if defined(__GNUC__)
-  /* for GCC we try to use GNUC_PACKED */
-# define PRAGMA_BEGIN_PACKED
-# define PRAGMA_END_PACKED
-#elif defined(HAVE_ISOC99_PRAGMA)
-  /* should work with most EDG-frontend based compilers */
-# define PRAGMA_BEGIN_PACKED _Pragma("pack(1)")
-# define PRAGMA_END_PACKED   _Pragma("pack()")
+#if defined(__MINGW32__)
+#  define PRAGMA_BEGIN_PACKED _Pragma("pack(push)") \
+                              _Pragma("pack(1)")
+#  define PRAGMA_END_PACKED   _Pragma("pack(pop)")
+#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ >= 199901)
+     /* should work with most EDG-frontend based compilers */
+#    define PRAGMA_BEGIN_PACKED _Pragma("pack(1)")
+#    define PRAGMA_END_PACKED   _Pragma("pack()")
+#elif defined(_MSC_VER)
+#  define PRAGMA_BEGIN_PACKED __pragma(pack(push, 1))
+#  define PRAGMA_END_PACKED   __pragma(pack(pop))
 #else /* neither gcc nor _Pragma() available... */
-  /* ...so let's be naive and hope the regression testsuite is run... */
-# define PRAGMA_BEGIN_PACKED
-# define PRAGMA_END_PACKED
+   /* ...so let's be naive and hope the regression testsuite is run... */
+#  define PRAGMA_BEGIN_PACKED
+#  define PRAGMA_END_PACKED
 #endif
   
   /*
@@ -174,8 +182,22 @@ typedef uint8_t ubyte;
 #ifndef NULL
 # define NULL ((void*) 0)
 #endif
-  
-  /* our own offsetof()-like macro */
+
+  /** Provide a notice for deprecated elements. Before gcc 4.5 'deprecated'
+   takes no arguments. */
+#if defined(__GNUC__)
+# if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 5)
+#   define LIBCDIO_DEPRECATED(object, notice) object __attribute__ ((deprecated(notice)))
+# else
+#   define LIBCDIO_DEPRECATED(object, notice) object __attribute__ ((deprecated))
+# endif
+#elif defined(_MSC_VER)
+#define LIBCDIO_DEPRECATED(object, notice) __declspec(deprecated(notice)) object
+#else
+#define LIBCDIO_DEPRECATED(object, notice)
+#endif
+
+  /** our own offsetof()-like macro */
 #define __cd_offsetof(TYPE, MEMBER) ((size_t) &((TYPE *)0)->MEMBER)
   
   /*!
@@ -243,10 +265,10 @@ typedef uint8_t ubyte;
   typedef int32_t lsn_t;
   
   /* Address in either MSF or logical format */
-  union cdio_cdrom_addr		
+  union cdio_cdrom_addr         
   {
-    msf_t	msf;
-    lba_t	lba;
+    msf_t       msf;
+    lba_t       lba;
   };
 
   /*! The type of a track number 0..99. */
@@ -274,6 +296,7 @@ typedef uint8_t ubyte;
 
   /*! 
     Number of ASCII bytes in a media catalog number (MCN).
+    We include an extra 0 byte so these can be used as C strings.
   */
 #define CDIO_MCN_SIZE       13
 
@@ -290,7 +313,7 @@ typedef uint8_t ubyte;
 #define CDIO_ISRC_SIZE       12
 
   /*! 
-    Type to hold ASCII bytes in a media catalog number (MCN).
+    Type to hold ASCII bytes in a ISRC.
     We include an extra 0 byte so these can be used as C strings.
   */
   typedef char cdio_isrc_t[CDIO_ISRC_SIZE+1];
@@ -302,20 +325,20 @@ typedef uint8_t ubyte;
     Q Sub-channel Control Field (4.2.3.3)
   */
   typedef enum {
-    CDIO_TRACK_FLAG_NONE = 		 0x00,	/**< no flags set */
-    CDIO_TRACK_FLAG_PRE_EMPHASIS =	 0x01,	/**< audio track recorded with
+    CDIO_TRACK_FLAG_NONE =               0x00,  /**< no flags set */
+    CDIO_TRACK_FLAG_PRE_EMPHASIS =       0x01,  /**< audio track recorded with
                                                    pre-emphasis */
-    CDIO_TRACK_FLAG_COPY_PERMITTED =	 0x02,	/**< digital copy permitted */
-    CDIO_TRACK_FLAG_DATA =		 0x04,	/**< data track */
+    CDIO_TRACK_FLAG_COPY_PERMITTED =     0x02,  /**< digital copy permitted */
+    CDIO_TRACK_FLAG_DATA =               0x04,  /**< data track */
     CDIO_TRACK_FLAG_FOUR_CHANNEL_AUDIO = 0x08,  /**< 4 audio channels */
-  CDIO_TRACK_FLAG_SCMS =		 0x10	/**< SCMS (5.29.2.7) */
+  CDIO_TRACK_FLAG_SCMS =                 0x10   /**< SCMS (5.29.2.7) */
 } cdio_track_flag;
 
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
 
-#endif /* __CDIO_TYPES_H__ */
+#endif /* CDIO_TYPES_H_ */
 
 
 /* 
