@@ -1,6 +1,4 @@
 /*
-  $Id: win32.h,v 1.11 2008/04/21 18:30:21 karl Exp $
-
   Copyright (C) 2004, 2005, 2008 Rocky Bernstein <rocky@gnu.org>
 
   This program is free software: you can redistribute it and/or modify
@@ -25,7 +23,6 @@ typedef struct {
   lsn_t          start_lsn;
   UCHAR          Control : 4;
   UCHAR          Format;
-  cdtext_t       cdtext;	         /* CD-TEXT */
 } track_info_t;
 
 typedef enum {
@@ -48,7 +45,7 @@ typedef struct {
   track_info_t  tocent[CDIO_CD_MAX_TRACKS+1];
 
   HANDLE h_device_handle; /* device descriptor */
-  long  hASPI;
+  HMODULE hASPI;
   short i_sid;
   short i_lun;
   long  (*lpSendCommand)( void* );
@@ -197,14 +194,6 @@ bool read_toc_win32ioctl (_img_private_t *p_env);
  */
 char *get_mcn_win32ioctl (const _img_private_t *p_env);
 
-/*
-  Read cdtext information for a CdIo object .
-  
-  return true on success, false on error or CD-TEXT information does
-  not exist.
-*/
-bool init_cdtext_win32ioctl (_img_private_t *p_env);
-
 /*!
   Return the the kind of drive capabilities of device.
 
@@ -234,8 +223,3 @@ void get_drive_cap_win32ioctl (const _img_private_t *p_env,
 */
 track_format_t get_track_format_win32ioctl(const _img_private_t *p_env, 
 					   track_t i_track); 
-
-void set_cdtext_field_win32(void *user_data, track_t i_track, 
-			    track_t i_first_track,
-			    cdtext_field_t e_field, const char *psz_value);
-
