@@ -309,8 +309,8 @@ bool cdio_charset_from_utf8(cdio_utf8_t * src, char ** dst,
   return true;
   }
 
-bool cdio_charset_to_utf8(char *src, size_t src_len, cdio_utf8_t **dst,
-                          const char * src_charset)
+bool cdio_charset_to_utf8(const char *src, size_t src_len, cdio_utf8_t **dst,
+                          const char *src_charset)
   {
   wchar_t* le_src;
   int i;
