@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2005, 2006, 2008, 2009, 2010, 2011
+  Copyright (C) 2005, 2006, 2008, 2009, 2010, 2011, 2012
   Rocky Bernstein <rocky@gnu.org>
 
   Adapted from Gerd Knorr's player.c program  <kraxel@bytesex.org>
@@ -40,7 +40,9 @@
 #include <string.h>
 #endif
 
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 
 #ifdef HAVE_CDDB
 #include <cddb/cddb.h>
@@ -53,13 +55,17 @@
 #endif
 
 #ifdef HAVE_CURSES_H
-#include <curses.h>
+# include <curses.h>
 #else 
-#ifdef HAVE_NCURSES_H
+# ifdef HAVE_NCURSES_H
 #include <ncurses.h>
-#else
-#  error "You need <curses.h> or <ncurses.h to build cdda-player"
-#endif
+# else
+#   ifdef HAVE_NCURSES_NCURSES_H
+#     include <ncurses/ncurses.h>
+#   else 
+#     error "You need <curses.h> or <ncurses.h to build cdda-player"
+#   endif
+# endif
 #endif
 
 #include <cdio/cdio.h>
@@ -537,23 +543,22 @@ get_cddb_disc_info(CdIo_t *p_cdio)
   return;
 }
 
-#define add_cdtext_disc_info(format_str, info_field, FIELD) \
-  if (p_cdtext->field[FIELD] && !strlen(info_field)) {      \
-    snprintf(info_field, sizeof(info_field), format_str,    \
-             p_cdtext->field[FIELD]);                       \
-    b_cdtext_ ## info_field = true;                         \
+#define add_cdtext_disc_info(format_str, info_field, FIELD)     \
+  if (cdtext_get_const(p_cdtext, FIELD, 0) && !strlen(info_field)) { \
+    snprintf(info_field, sizeof(info_field), format_str,        \
+             cdtext_get_const(p_cdtext, FIELD, 0));                  \
+    b_cdtext_ ## info_field = true;                             \
   }
 
 static void 
 get_cdtext_disc_info(CdIo_t *p_cdio) 
 {
-  cdtext_t *p_cdtext = cdio_get_cdtext(p_cdio, 0);
+  cdtext_t *p_cdtext = cdio_get_cdtext(p_cdio);
 
   if (p_cdtext) {
-    add_cdtext_disc_info("%s", title, CDTEXT_TITLE);
-    add_cdtext_disc_info("%s", artist, CDTEXT_PERFORMER);
-    add_cdtext_disc_info("%s", genre, CDTEXT_GENRE);
-    cdtext_destroy(p_cdtext);
+    add_cdtext_disc_info("%s", title, CDTEXT_FIELD_TITLE);
+    add_cdtext_disc_info("%s", artist, CDTEXT_FIELD_PERFORMER);
+    add_cdtext_disc_info("%s", genre, CDTEXT_FIELD_GENRE);
   }
 }
 
@@ -835,10 +840,10 @@ get_cddb_track_info(track_t i_track)
 }
 
 #define add_cdtext_track_info(format_str, info_field, FIELD) \
-  if (p_cdtext->field[FIELD]) {                              \
-    snprintf(cd_info[i_track].info_field,                    \
-             sizeof(cd_info[i_track].info_field),            \
-             format_str, p_cdtext->field[FIELD]);            \
+  if (cdtext_get_const(p_cdtext, FIELD, i_track)) {                        \
+    snprintf(cd_info[i_track].info_field,                             \
+             sizeof(cd_info[i_track].info_field),                     \
+             format_str, cdtext_get_const(p_cdtext, FIELD, i_track));      \
     cd_info[i_track].b_cdtext = true; \
   }
 
@@ -847,12 +852,11 @@ static void
 get_cdtext_track_info(track_t i_track)
 {
 
-  cdtext_t *p_cdtext = cdio_get_cdtext(p_cdio, i_track);
+  cdtext_t *p_cdtext = cdio_get_cdtext(p_cdio);
 
   if (NULL != p_cdtext) {
-    add_cdtext_track_info("%s", title, CDTEXT_TITLE);
-    add_cdtext_track_info("%s", artist, CDTEXT_PERFORMER);
-    cdtext_destroy(p_cdtext);
+    add_cdtext_track_info("%s", title, CDTEXT_FIELD_TITLE);
+    add_cdtext_track_info("%s", artist, CDTEXT_FIELD_PERFORMER);
   }
 }
 
@@ -960,13 +964,12 @@ print_keys()
 static void 
 keypress_wait(CdIo_t *p_cdio)
   {
-    int key;
     action("press any key to continue");
     while (1 != select_wait(b_cd ? 1 : 5)) {
       read_subchannel(p_cdio);
       display_status(true);
     }
-    key = getch();
+    (void) getch();
     clrtobot();
     action(NULL);
     if (!b_all_tracks)
