@@ -1,7 +1,7 @@
 /*
-  Copyright (C) 2003-2005, 2011-2012  Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 2003-2005, 2011-2013  Rocky Bernstein <rocky@gnu.org>
   Copyright (C) 2008 Robert W. Fuller <hydrologiccycle@gmail.com>
-  
+
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
@@ -16,9 +16,13 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/* 
+/*
    Regression test for cdio_get_pregap_lsn()
+
+   To compile as a standalone program:
+   gcc -g3 -Wall -DHAVE_CONFIG_H -I.. -I../include testpregap.c ../lib/driver/.libs/libcdio.a -o testpregap
 */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #define __CDIO_CONFIG_H__ 1
@@ -45,7 +49,7 @@
 #define DATA_DIR "./data"
 #endif
 
-static void 
+static void
 log_handler (cdio_log_level_t level, const char message[])
 {
   switch(level) {
@@ -67,20 +71,18 @@ typedef struct _pregap_list_t {
 
 static pregap_list_t pregapList[] =
 {
-    { "/src/external-vcs/libcdio/test/data/t2.toc", 1, 4425 },
-    { "/src/external-vcs/libcdio/test/data/t2.toc", 2, CDIO_INVALID_LSN },
-    { "/src/external-vcs/libcdio/test/data/p1.cue", 1, 0 },
-    { "/src/external-vcs/libcdio/test/data/p1.cue", 2, 150 },
-    { "/src/external-vcs/libcdio/test/data/p1.cue", 3, CDIO_INVALID_LSN },
+    { "/src/external-vcs/savannah/libcdio/test/data/t2.toc", 1, 4425 },
+    { "/src/external-vcs/savannah/libcdio/test/data/t2.toc", 2, CDIO_INVALID_LSN },
+    { "/src/external-vcs/savannah/libcdio/test/data/p1.cue", 1, 0 },
+    { "/src/external-vcs/savannah/libcdio/test/data/p1.cue", 2, 150 },
+    { "/src/external-vcs/savannah/libcdio/test/data/p1.cue", 3, CDIO_INVALID_LSN },
 /*    { "p1.nrg", 1, 0 }, Nero did not create the proper pre-gap - bleh */
-    { "/src/external-vcs/libcdio/test/data/p1.nrg", 2, 225 },
-    { "/src/external-vcs/libcdio/test/data/p1.nrg", 3, CDIO_INVALID_LSN }
+    { "/src/external-vcs/savannah/libcdio/test/data/p1.nrg", 2, 225 },
+    { "/src/external-vcs/savannah/libcdio/test/data/p1.nrg", 3, CDIO_INVALID_LSN }
 };
 
 #define NELEMS(v) (sizeof(v) / sizeof(v[0]))
 
-/* gcc -Wall -I../include testpregap.c ../lib/driver/.libs/libcdio.a */
-
 int
 main(int argc, const char *argv[])
 {
@@ -89,7 +91,7 @@ main(int argc, const char *argv[])
   lsn_t pregap;
   int i;
   int rc = 0;
-  
+
   cdio_log_set_handler (log_handler);
 
   if (! (cdio_have_driver(DRIVER_NRG) && cdio_have_driver(DRIVER_BINCUE)
@@ -110,8 +112,8 @@ main(int argc, const char *argv[])
 
     pregap = cdio_get_track_pregap_lsn(cdObj, pregapList[i].track);
     if (pregap != pregapList[i].pregap) {
-      printf("-- %s should have had pregap of lsn=%d instead of lsn=%d\n",
-       image, pregapList[i].pregap, pregap);
+      printf("%s should have had pregap of lsn=%d instead of lsn=%d\n",
+	     image, pregapList[i].pregap, pregap);
       rc = i + 1;
     } else {
       printf("-- %s had expected pregap\n", image);
